FacPad-package: Sparse factor modeling for the inference of drug-responsive pathways
Description
This method tries to explain the gene-wise treatment response ratios in terms of
the latent pathways. It uses bayesian sparse factor modeling to infer the loadings
(weights) of each pathway on its associated probesets as well as the latent factor
activity levels for each treatment.