gibbs2: A Collapsed Gibbs Sampling Algorithm for the Inference
of Sparse Bayesian Factor Models_version2
Description
In each iteration, the algorithm iteratively
updates each entry in the binary matrix Z, loading matrix W
and factor activity matrix X, as well as other model parameters.
The algorithm will store the inferred binary indicator matrix Z,
loading matrix W and factor activity matrix X
(as well as tau_g if not pre-difined) in each thinned iteration
and write them into .RData file with name defined by the user.